/**
 * Helper functions to print out module/group feedback
 */

#include <stdio.h>
#include <inttypes.h>

#include "hebi_feedback.h"
#include "hebi_group_feedback.h"

void print_module_feedback(HebiFeedbackPtr feedback)
{
  // The feedback object contains many fields and subobjects, depending on
  // the type of feedback. Here we get a subcommand of this object which
  // contains relevant feedback for actuators, such as position, velocity,
  // and torque:
  int64_t revs; float offset;
  hebiFeedbackGetHighResAngle(feedback, FeedbackHighResAnglePosition, &revs, &offset),
  printf("Position %" PRId64 " + %f | Velocity %f | Torque %f\n",
    revs, offset,
    hebiFeedbackGetFloat(feedback, FeedbackFloatVelocity),
    hebiFeedbackGetFloat(feedback, FeedbackFloatTorque));
}

void print_group_feedback(HebiGroupFeedbackPtr group_feedback)
{
  int num_modules = hebiGroupFeedbackGetNumModules(group_feedback);
  int mod_idx;
  for (mod_idx = 0; mod_idx < num_modules; mod_idx++)
  {
    printf("Module index: %d\n", mod_idx);
    HebiFeedbackPtr module_feedback =
      hebiGroupFeedbackGetModuleFeedback(group_feedback, mod_idx);
    print_module_feedback(module_feedback);
  }
}
